@@ -2,7 +2,6 @@ import asyncio
 import time
 import traceback
 from typing import Awaitable
-from asyncio.exceptions import CancelledError
 from binding import BindableProperty
 from .elements.element import Element
 from .utils import handle_exceptions
@@ -46,7 +45,7 @@ class Timer:
                             await parent.update()
                     dt = time.time() - start
                     await asyncio.sleep(interval - dt)
-                except CancelledError:
+                except asyncio.CancelledError:
                     pass
                 except:
                     traceback.print_exc()
